﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using TilesForWinPhone8.Resources;
using System.IO.IsolatedStorage;
using System.Windows.Media.Imaging;
using System.Windows.Resources;
using System.Windows.Input;
using Windows.Phone.System.UserProfile;

namespace TilesForWinPhone8
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Set the data context of the listbox control to the sample data
            DataContext = App.ViewModel;

            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();
        }

        // Load data for the ViewModel Items
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            if (!App.ViewModel.IsDataLoaded)
            {
                App.ViewModel.LoadData();
            }
        }

        private void CreateFlipTile(object sender, System.Windows.RoutedEventArgs e)
        {
            FlipTileData ftd = new FlipTileData();
            
            // Set up text data
            ftd.Title = flip_title.Text;
            ftd.BackContent = flip_backText.Text;
            ftd.WideBackContent = flip_WideBackText.Text;            
            
            // Set up image data
            string imageLoc = GetMediumFlipUri();
            ftd.BackgroundImage = new Uri(imageLoc, UriKind.Relative);
            ftd.SmallBackgroundImage = ftd.BackgroundImage;
            string wideImageLoc = GetLargeFlipUri();
            ftd.WideBackgroundImage = new Uri(wideImageLoc, UriKind.Relative);

            string uniqueParameter = (Guid.NewGuid()).ToString();
            ShellTile.Create(new Uri("/MainPage.xaml?junkParam=" + uniqueParameter, UriKind.Relative), ftd, true);
            // Create Tile
            //ShellTile.Create(new Uri("/MainPage.xaml", UriKind.Relative), ftd, true);

        }

        private void CreateIconTile(object sender, System.Windows.RoutedEventArgs e)
        {
            IconicTileData itd = new IconicTileData();

            // Set up count
            itd.Count = Convert.ToInt32(iconicCount.Text);

            // Set up text data
            itd.Title = iconicTitle.Text;
            itd.WideContent1 = iconicWideContent1.Text;
            itd.WideContent2 = iconicWideContent2.Text;
            itd.WideContent3 = iconicWideContent3.Text;

            // Set up image data
            itd.IconImage = new Uri("Assets/Tiles/Channel9_Guy_icon.png", UriKind.Relative);
            
            // Create icon tile
            string uniqueParameter = (Guid.NewGuid()).ToString();
            IsolatedStorageSettings.ApplicationSettings["iconTile"] = new Uri("/MainPage.xaml?junkParam=" + uniqueParameter, UriKind.Relative);
            IsolatedStorageSettings.ApplicationSettings.Save();
            ShellTile.Create(new Uri("/MainPage.xaml?junkParam=" + uniqueParameter, UriKind.Relative), itd, true);
        }

        private void CreateCycleTile(object sender, System.Windows.RoutedEventArgs e)
        {
            CycleTileData ctd = new CycleTileData();

            // Set up text data
            ctd.Title = cycleTileText.Text;

            // Set up image data
            ctd.SmallBackgroundImage = new Uri("Assets/Tiles/Medium_Image_1.jpg", UriKind.Relative);
            List<Uri> cycleImages = new List<Uri>();

            if (cycle_tile_1.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_1.jpg", UriKind.Relative));
            if (cycle_tile_2.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_2.jpg", UriKind.Relative));
            if (cycle_tile_3.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_3.jpg", UriKind.Relative));
            if (cycle_tile_4.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_4.jpg", UriKind.Relative));
            if (cycle_tile_5.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_5.jpg", UriKind.Relative));
            if (cycle_tile_6.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_6.jpg", UriKind.Relative));

            ctd.CycleImages = cycleImages;
            // Create Tile
            string uniqueParameter = (Guid.NewGuid()).ToString();
            ShellTile.Create(new Uri("/MainPage.xaml?junkParam=" + uniqueParameter, UriKind.Relative), ctd, true);
        }

        ShellTileSchedule TileSchedule = new ShellTileSchedule();

        private void ScheduleTileUpdate(object sender, System.EventArgs e)
        {
            ShellTile myTile = null;
            Uri iconTile = (Uri)IsolatedStorageSettings.ApplicationSettings["iconTile"];
            foreach(ShellTile st in ShellTile.ActiveTiles){
                if(st.NavigationUri == iconTile)
                    myTile = st;
            }
            if (myTile != null)
            {
                IconicTileData itd = new IconicTileData();

                // Set up count
                itd.Count = 30;

                // Set up text data
                itd.Title = iconicTitle.Text;
                itd.WideContent1 = iconicWideContent1.Text;
                itd.WideContent2 = iconicWideContent2.Text;
                itd.WideContent3 = iconicWideContent3.Text;

                // Set up image data
                itd.IconImage = new Uri("Assets/Tiles/Channel9_Guy_icon.png", UriKind.Relative);

                TileSchedule = new ShellTileSchedule(myTile, itd);
                // This update will happen 1 time
                TileSchedule.Recurrence = UpdateRecurrence.Onetime;
                TileSchedule.StartTime = DateTime.Now;
                // Updates will apply to the application tile. 
                TileSchedule.Start();
            }
        }

        private async void EnableLockIcon(object sender, System.Windows.RoutedEventArgs e)
        {
            Windows.System.Launcher.LaunchUriAsync(new System.Uri("ms-settings-lock:"));
        }

        private void LockScreenTileUpdate(object sender, System.EventArgs e)
        {
            ShellTile myTile = null;
            Uri iconTile = (Uri)IsolatedStorageSettings.ApplicationSettings["iconTile"];
            foreach (ShellTile st in ShellTile.ActiveTiles)
            {
                if (st.NavigationUri.OriginalString == "/")
                    myTile = st;
            }
            
            if (myTile != null)
            {
                IconicTileData itd = new IconicTileData();
                itd.Count = 24;

                TileSchedule = new ShellTileSchedule(myTile, itd );
                // This update will happen 1 time
                TileSchedule.Recurrence = UpdateRecurrence.Interval;
                TileSchedule.Interval = UpdateInterval.EveryHour;
                TileSchedule.MaxUpdateCount = 5;
                TileSchedule.StartTime = DateTime.Now;
                // Updates will apply to the application tile. 
                TileSchedule.Start();
            }
        }


        #region Helper Methods

        private List<Uri> AddCycleImages()
        {
            List<Uri> cycleImages = new List<Uri>();

            if (cycle_tile_1.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_1.jpg", UriKind.Relative));
            if (cycle_tile_2.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_2.jpg", UriKind.Relative));
            if (cycle_tile_3.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_3.jpg", UriKind.Relative));
            if (cycle_tile_4.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_4.jpg", UriKind.Relative));
            if (cycle_tile_5.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_5.jpg", UriKind.Relative));
            if (cycle_tile_6.IsChecked == true)
                cycleImages.Add(new Uri("Assets/Tiles/Wide_Image_6.jpg", UriKind.Relative));
            return cycleImages;
        }

        private string GetMediumFlipUri()
        {
            if (flip_img_1.IsChecked == true)
                return "Assets/Tiles/Medium_Image_1.jpg";
            else if (flip_img_2.IsChecked == true)
                return "Assets/Tiles/Medium_Image_2.jpg";
            else if (flip_img_3.IsChecked == true)
                return "Assets/Tiles/Medium_Image_3.jpg";
            else if (flip_img_4.IsChecked == true)
                return "Assets/Tiles/Medium_Image_4.jpg";
            else if (flip_img_5.IsChecked == true)
                return "Assets/Tiles/Medium_Image_5.jpg";
            else
                return "Assets/Tiles/Medium_Image_6.jpg";
        }

        private string GetLargeFlipUri()
        {
            if (flip_wide_img_1.IsChecked == true)
                return "Assets/Tiles/Wide_Image_1.jpg";
            else if (flip_wide_img_2.IsChecked == true)
                return "Assets/Tiles/Wide_Image_2.jpg";
            else if (flip_wide_img_3.IsChecked == true)
                return "Assets/Tiles/Wide_Image_3.jpg";
            else if (flip_wide_img_4.IsChecked == true)
                return "Assets/Tiles/Wide_Image_4.jpg";
            else if (flip_wide_img_5.IsChecked == true)
                return "Assets/Tiles/Wide_Image_5.jpg";
            else
                return "Assets/Tiles/Wide_Image_6.jpg";
        }

        private Uri ProcessImageForTile(string fileLocation, string fileName, TileSize ts)
        {
            IsolatedStorageFile store = IsolatedStorageFile.GetUserStoreForApplication();
            const string shellDirectory = "Shared\\ShellContent";
            store.CreateDirectory(shellDirectory);
            StreamResourceInfo sri = Application.GetResourceStream(new Uri(fileLocation, UriKind.Relative));
            BitmapImage bmi = new BitmapImage();
            bmi.SetSource(sri.Stream);

            WriteableBitmap wbmp = new WriteableBitmap(bmi);
            string imagePath = shellDirectory + "\\" + fileName + ".jpg";
            if (ts == TileSize.Icon)
                imagePath = shellDirectory + "\\" + fileName + ".png";
            if (store.FileExists(imagePath))
                store.DeleteFile(imagePath);
            int imgWidth = 159;
            int imgHeight = 159;
            if (ts == TileSize.Medium)
                imgWidth = imgHeight = 336;
            else if (ts == TileSize.Wide)
            {
                imgWidth = 691;
                imgHeight = 336;
            }
            else if (ts == TileSize.Icon)
                imgWidth = imgHeight = 202;
        
            using (IsolatedStorageFileStream stream = store.OpenFile(imagePath, System.IO.FileMode.OpenOrCreate))
            {
                wbmp.SaveJpeg(stream, imgWidth, imgHeight, 0, 100);
                return new Uri("isostore:/" + imagePath.Replace('\\', '/')); 
            }
        }
        #endregion

        private void FilterNonNumbers(object sender, System.Windows.Input.KeyEventArgs e)
        {
            if (e.Key != Key.D1 && e.Key != Key.D2 && e.Key != Key.D3 &&
                e.Key != Key.D4 && e.Key != Key.D5 && e.Key != Key.D6 &&
                e.Key != Key.D7 && e.Key != Key.D8 && e.Key != Key.D9 &&
                e.Key != Key.D0)
            {
                e.Handled = true;
            }
        }

        

        

        

        

        enum TileSize
        {
            Small, 
            Medium,
            Wide,
            Icon
        }

        // Sample code for building a localized ApplicationBar
        //private void BuildLocalizedApplicationBar()
        //{
        //    // Set the page's ApplicationBar to a new instance of ApplicationBar.
        //    ApplicationBar = new ApplicationBar();

        //    // Create a new button and set the text value to the localized string from AppResources.
        //    ApplicationBarIconButton appBarButton = new ApplicationBarIconButton(new Uri("/Assets/AppBar/appbar.add.rest.png", UriKind.Relative));
        //    appBarButton.Text = AppResources.AppBarButtonText;
        //    ApplicationBar.Buttons.Add(appBarButton);

        //    // Create a new menu item with the localized string from AppResources.
        //    ApplicationBarMenuItem appBarMenuItem = new ApplicationBarMenuItem(AppResources.AppBarMenuItemText);
        //    ApplicationBar.MenuItems.Add(appBarMenuItem);
        //}
    }
}